# labquiz

Integration of quizzes in jupyter notebooks
- For self-assessment and evaluation
- Also featuring realtime monitoring and correction. 

Companion programs: 
- quiz_editor: [streamlit app](https://jfb-quizeditor.streamlit.app/) | [src code](https://github.com/jfbercher/quiz_editor)
- quiz_dash: [streamlit app](https://jfb-quizdash.streamlit.app/) | [src code](https://github.com/jfbercher/quiz_dash)
  

Sponsor:

![https://wwww.esiee.fr](esiee_logo_moyen.png)
